import requests
from bs4 import BeautifulSoup


def jsext(url,outfile):
    source = requests.get(url).text
    soup = BeautifulSoup(source ,'lxml')

    for article in soup.find_all('script'):
        try:
            if (article.text.strip()).startswith('init'):
                url=article.text.strip().split('"')[3]
                if url.startswith('https'):
                    iscript=requests.get(url).json()
                    pt=iscript['path']
                    if outfile==None:
                        print('\n')
                        print(iscript['dependencies'][pt].encode('utf-8').strip())
                    else:
                        file=open(outfile, 'w')
                        file.write(iscript['dependencies'][pt].encode('utf-8').strip())
                        file.close()
                        clean_lines = []
                        with open(outfile, "r") as f:
                            lines = f.readlines()
                            clean_lines = [l.strip() for l in lines if l.strip()]
                        with open(outfile, "w") as f:
                            f.writelines('\n'.join(clean_lines))
        except Exception as e:
            print(e)
#jsext(url='https://globalfires.earthengine.app/view/gfedv4s-monthly-ba-animated')
#jsext(url='https://bullocke.users.earthengine.app/view/amazon')




__copyright__ = """

    Copyright 2016 Lukasz Tracewski

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
__license__ = "Apache 2.0"


import fnmatch
import logging
import sys

import ee


def delete(asset_path):
    root = asset_path[:asset_path.rfind('/')]
    all_assets_names = [e['id'] for e in ee.data.getList({'id': root})]
    filtered_names = fnmatch.filter(all_assets_names, asset_path)
    if not filtered_names:
        logging.warning('Nothing to remove. Exiting.')
        sys.exit(1)
    else:
        for path in filtered_names:
            __delete_recursive(path)
            logging.info('Collection %s removed', path)


def __delete_recursive(asset_path):
    info = ee.data.getInfo(asset_path)
    if not info:
        logging.warning('Nothing to delete.')
        sys.exit(1)
    elif info['type'] == 'Image':
        pass
    elif info['type'] == 'Folder':
        items_in_destination = ee.data.getList({'id': asset_path})
        for item in items_in_destination:
            logging.info('Removing items in %s folder', item['id'])
            delete(item['id'])
    else:
        items_in_destination = ee.data.getList({'id': asset_path})
        for item in items_in_destination:
            ee.data.deleteAsset(item['id'])
    ee.data.deleteAsset(asset_path)



import ee
import subprocess
import csv
import os

##initialize earth engine
ee.Initialize()


suffixes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB']
def humansize(nbytes):
    i = 0
    while nbytes >= 1024 and i < len(suffixes)-1:
        nbytes /= 1024.
        i += 1
    f = ('%.2f' % nbytes).rstrip('0').rstrip('.')
    return '%s %s' % (f, suffixes[i])

def object_sz(object):
    sz=humansize(object.get('system:asset_size').getInfo())
    return sz

def collect_sz(object):
    sz=humansize(object.reduceColumns(ee.Reducer.sum(), ['system:asset_size']).get('sum').getInfo())
    return sz

def lst(location, typ, items=None,output=None):
    if items is None and typ =='print':
        assets_list = ee.data.getList(params={'id': location})
        for things in assets_list:
            header=things['type']
            tail=things['id']
            try:
                if header=="ImageCollection":
                    collc=ee.ImageCollection(tail)
                    ast=collc.size().getInfo()
                    sz=collect_sz(collc)
                    print("Image Collection: "+str(tail)+" has "+str(ast)+" images a total of "+str(sz))
                elif header=="Image":
                    collc=ee.Image(tail)
                    sz=object_sz(collc)
                    print("Image: "+str(tail)+" is "+str(sz))
                elif header=="Table":
                    collc=ee.FeatureCollection(tail)
                    sz=object_sz(collc)
                    print("Table: "+str(tail)+" is "+str(sz))
                elif header=="Folder": ##Folders are not added to the list but are print
                    assets_list = ee.data.getList(params={'id': location})
                    print("Folder: "+str(tail) +" has "+str(len(assets_list)))
            except Exception as e:
                print(e)
    elif items >0 and typ =='print':
        assets_list = ee.data.getList(params={'id': location})
        if int(len(assets_list))>int(items):
            subset=assets_list[:int(items)]
            for things in subset:
                header=things['type']
                tail=things['id']
                try:
                    if header=="ImageCollection":
                        collc=ee.ImageCollection(tail)
                        ast=collc.size().getInfo()
                        sz=collect_sz(collc)
                        print("Image Collection: "+str(tail)+" has "+str(ast)+" images a total of "+str(sz))
                    elif header=="Image":
                        collc=ee.Image(tail)
                        sz=object_sz(collc)
                        print("Image: "+str(tail)+" is "+str(sz))
                    elif header=="Table":
                        collc=ee.FeatureCollection(tail)
                        sz=object_sz(collc)
                        print("Table: "+str(tail)+" is "+str(sz))
                    elif header=="Folder": ##Folders are not added to the list but are print
                        assets_list = ee.data.getList(params={'id': location})
                        print("Folder: "+str(tail) +" has "+str(len(assets_list)))
                except Exception as e:
                    print(e)
    elif items is None and typ =='report':
        with open(output,"wb") as csvfile:
            writer=csv.DictWriter(csvfile,fieldnames=["type", "path","No of Assets","size"], delimiter=',')
            writer.writeheader()
        assets_list = ee.data.getList(params={'id': location})
        for things in assets_list:
            header=things['type']
            tail=things['id']
            try:
                if header=="ImageCollection":
                    collc=ee.ImageCollection(tail)
                    ast=collc.size().getInfo()
                    sz=collect_sz(collc)
                    print("Image Collection: "+str(tail)+" has "+str(ast)+" images a total of "+str(sz))
                    with open(output,"a") as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([header,tail,ast,str(sz)])
                    csvfile.close()
                elif header=="Image":
                    collc=ee.Image(tail)
                    sz=object_sz(collc)
                    print("Image: "+str(tail)+" is "+str(sz))
                    with open(output,"a") as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([header,tail,ast,str(sz)])
                    csvfile.close()
                elif header=="Table":
                    collc=ee.FeatureCollection(tail)
                    sz=object_sz(collc)
                    print("Table: "+str(tail)+" is "+str(sz))
                    with open(output,"a") as csvfile:
                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                        writer.writerow([header,tail,ast,str(sz)])
                    csvfile.close()
                elif header=="Folder": ##Folders are not added to the list but are print
                    assets_list = ee.data.getList(params={'id': location})
                    print("Folder: "+str(tail) +" has "+str(len(assets_list)))
            except Exception as e:
                print(e)
    elif items > 0 and typ =='report':
        with open(output,"wb") as csvfile:
            writer=csv.DictWriter(csvfile,fieldnames=["type", "path","No of Assets","size"], delimiter=',')
            writer.writeheader()
        assets_list = ee.data.getList(params={'id': location})
        if int(len(assets_list))>int(items):
            subset=assets_list[:int(items)]
            for things in subset:
                header=things['type']
                tail=things['id']
                try:
                    if header=="ImageCollection":
                        collc=ee.ImageCollection(tail)
                        ast=collc.size().getInfo()
                        sz=collect_sz(collc)
                        print("Image Collection: "+str(tail)+" has "+str(ast)+" images a total of "+str(sz))
                        with open(output,"a") as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([header,tail,ast,str(sz)])
                        csvfile.close()
                    elif header=="Image":
                        collc=ee.Image(tail)
                        sz=object_sz(collc)
                        print("Image: "+str(tail)+" is "+str(sz))
                        with open(output,"a") as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([header,tail,1,str(sz)])
                        csvfile.close()
                    elif header=="Table":
                        collc=ee.FeatureCollection(tail)
                        sz=object_sz(collc)
                        print("Table: "+str(tail)+" is "+str(sz))
                        with open(output,"a") as csvfile:
                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
                            writer.writerow([header,tail,1,str(sz)])
                        csvfile.close()
                    elif header=="Folder": ##Folders are not added to the list but are print
                        assets_list = ee.data.getList(params={'id': location})
                        print("Folder: "+str(tail) +" has "+str(len(assets_list)))
                except Exception as e:
                    print(e)
#lst(location="users/samapriya/Belem", typ="report",items=0,output=r"C:\planet_demo\rep.csv")
